# Phaseref flux is overestimated in wet windows so correct this:
# fluxscale reported Flux density = 0.924+/-0.017 (freq=183.458 GHz) spidx=-2.6+/-2.6
# (this is error-weighted so it represents the good spw best)
# from calibrator catalogue 0.752 (0.069), spidx -0.9(0.1), age dif. 194 days
# so use current flux density (23% above catalogue) but more realistic spec.index -0.9
# (for the BP cal, the flux estimate here is only 4.5% higher than
# catalogue but the spectral index is also >twice as steep so it seems
# that our flux densities are probably OK.)

setjy(vis='uid___A002_Xb7c496_X4ab.ms.split.cal',
      field='J1700-2610',
      standard='manual',
      fluxdensity=[0.924,0,0,0],
      spix=-0.9,
      reffreq='183.458GHz')
      
os.system('rm -rf uid___A002_Xb7c496_X4ab.ms.split.cal_J1700-2610.fluxeq.a')
gaincal(vis='uid___A002_Xb7c496_X4ab.ms.split.cal',
        caltable='uid___A002_Xb7c496_X4ab.ms.split.cal_J1700-2610.fluxeq.a',
        field='J1700-2610',
        gaintype='T',
        calmode='a',
        solint='inf')

#if applyonly != True: es.checkCalTable('uid___A002_Xb7c496_X4ab.ms.split.cal_J1700-2610.fluxeq.a',msName='uid___A002_Xb7c496_X4ab.ms.split.cal',interactive=False) 
  
applycal(vis='uid___A002_Xb7c496_X4ab.ms.split.cal',
         field='J1700-2610,Sgr_B2N',
         gainfield='J1700-2610',
         gaintable='uid___A002_Xb7c496_X4ab.ms.split.cal_J1700-2610.fluxeq.a',
         calwt=F,flagbackup=F)


# Split out target and correct to constant velocity in target frame

spws=['0','1','2','3']
catvis=[]
for s in spws:
    os.system('rm -rf X4ab_Sgr_B2N_'+s+'.ms')
    mstransform(vis='uid___A002_Xb7c496_X4ab.ms.split.cal',
                outputvis='X4ab_Sgr_B2N_'+s+'.ms',
                datacolumn='corrected',
                field='Sgr_B2N',
                spw=s,
                keepflags=F,
                regridms=T,
                outframe='lsrk')
    catvis.append('X4ab_Sgr_B2N_'+s+'.ms')

# concatenate corrected target data
os.system('rm -rf X4ab_Sgr_B2N.ms.LSRK_FluxEqual_concat_183')
concat(vis=catvis,
       concatvis='X4ab_Sgr_B2N.ms.LSRK_FluxEqual_concat_183')

